"use strict";(self.webpackChunkeodag_labextension=self.webpackChunkeodag_labextension||[]).push([[5,767],{6005:(e,t,n)=>{n.r(t),n.d(t,{NonceProvider:()=>d,components:()=>h.c,createFilter:()=>o.c,default:()=>v,defaultTheme:()=>o.d,mergeStyles:()=>o.m,useStateManager:()=>r.u});var r=n(9234),a=n(5285),c=n(8893),o=n(3582),i=n(9542),u=n(6752),s=n(62),h=n(2737),l=n(9593),f=n(1326),m=n(1811),p=(n(9520),(0,c.forwardRef)((function(e,t){var n=(0,r.u)(e);return c.createElement(o.S,(0,a.A)({ref:t},n))}))),d=function(e){(0,s.A)(n,e);var t=(0,h._)(n);function n(e){var r;return(0,i.A)(this,n),(r=t.call(this,e)).createEmotionCache=function(e,t){return(0,f.A)({nonce:e,key:t})},r.createEmotionCache=(0,m.A)(r.createEmotionCache),r}return(0,u.A)(n,[{key:"render",value:function(){var e=this.createEmotionCache(this.props.nonce,this.props.cacheKey);return c.createElement(l.C,{value:e},this.props.children)}}]),n}(c.Component);const v=p}}]);